summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/clipboard/umlclipboard.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/clipboard/umlclipboard.h')
-rw-r--r--umbrello/umbrello/clipboard/umlclipboard.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/umbrello/umbrello/clipboard/umlclipboard.h b/umbrello/umbrello/clipboard/umlclipboard.h
index 9be92111..a4da299b 100644
--- a/umbrello/umbrello/clipboard/umlclipboard.h
+++ b/umbrello/umbrello/clipboard/umlclipboard.h
@@ -31,7 +31,7 @@ class QMimeSource;
* @author Gustavo Madrigal
* Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
*/
-class UMLClipboard : public QObject {
+class UMLClipboard : public TQObject {
Q_OBJECT
public:
/**
@@ -50,15 +50,15 @@ public:
* @param Data Pointer to the MIME format clipboard data.
* @return True for successful operation.
*/
- bool paste(QMimeSource* Data);
+ bool paste(TQMimeSource* Data);
/**
* Copies the selected stuff from the list view or current diagram
* to a QMimeSource ready to be put in the clipboard.
*
* @return Pointer to the created clipboard data.
*/
- QMimeSource* copy(bool fromView = false);
+ TQMimeSource* copy(bool fromView = false);
/// Enumeration that codes the different types of UML clips.
enum UMLCopyType
@@ -86,7 +86,7 @@ private:
* @param data Pointer to the source clip.
* @return True for successful operation.
*/
- bool pasteClip1(QMimeSource* data);
+ bool pasteClip1(TQMimeSource* data);
/**
* If clipboard has mime type application/x-uml-clip2,
@@ -95,7 +95,7 @@ private:
* @param data Pointer to the source clip.
* @return True for successful operation.
*/
- bool pasteClip2(QMimeSource* data);
+ bool pasteClip2(TQMimeSource* data);
/**
* If clipboard has mime type application/x-uml-clip3,
@@ -104,7 +104,7 @@ private:
* @param data Pointer to the source clip.
* @return True for successful operation.
*/
- bool pasteClip3(QMimeSource* data);
+ bool pasteClip3(TQMimeSource* data);
/**
* If clipboard has mime type application/x-uml-clip4,
@@ -113,7 +113,7 @@ private:
* @param data Pointer to the source clip.
* @return True for successful operation.
*/
- bool pasteClip4(QMimeSource* data);
+ bool pasteClip4(TQMimeSource* data);
/**
* If clipboard has mime type application/x-uml-clip5,
@@ -122,7 +122,7 @@ private:
* @param data Pointer to the source clip.
* @return True for successful operation.
*/
- bool pasteClip5(QMimeSource* data);
+ bool pasteClip5(TQMimeSource* data);
/**
* When pasting widgets see if they can be pasted on
@@ -50,15 +50,15 @@ public:
/**
* Copies the selected stuff from the list view or current diagram
- * to a QMimeSource ready to be put in the clipboard.
+ * to a TQMimeSource ready to be put in the clipboard.
*
* @return Pointer to the created clipboard data.